using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

namespace ToolWindowAddin
{
	/// <summary>
	/// Content of the tool window.
	/// </summary>
	public partial class DemoToolWindowControl : UserControl
	{
		/// <summary>
		/// Builds the tree node for the specified hierarchy item.
		/// </summary>
		/// <param name="item">The item.</param>
		/// <returns></returns>
		private TreeNode BuildTreeNode( HierarchyItem item )
		{
			TreeNode objTreeNode = new TreeNode( item.Text );
			foreach (HierarchyItem objChild in item.Children)
				objTreeNode.Nodes.Add( BuildTreeNode( objChild ) );

			return objTreeNode;
		}

		/// <summary>
		/// Handles the Click event of the c_btnUpdate control.
		/// </summary>
		/// <param name="sender">The source of the event.</param>
		/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
		private void c_btnUpdate_Click( object sender, EventArgs e )
		{
			OnRebuildRequested(EventArgs.Empty);
		}

		/// <summary>
		/// Raises the <see cref="E:RebuildRequested"/> event.
		/// </summary>
		/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
		protected virtual void OnRebuildRequested(EventArgs e)
		{
			EventHandler<EventArgs> handler = this.RebuildRequested;
			if (handler != null) handler(this, e);
		}

		//===================================================
		// Public
		//===================================================

		/// <summary>
		/// Occurs when the a rebuild of the tree has been requested by the user.
		/// </summary>
		public event EventHandler<EventArgs> RebuildRequested;

		/// <summary>
		/// Rebuilds the tree.
		/// </summary>
		public void BuildTree(HierarchyItem root)
		{
			c_tvwCodeElements.Nodes.Clear();
			c_tvwCodeElements.Nodes.Add(BuildTreeNode(root));
		}

		/// <summary>
		/// Initializes a new instance of the <see cref="DemoToolWindowControl"/> class.
		/// </summary>
		public DemoToolWindowControl()
		{
			InitializeComponent();
		}
	}
}
