using System;
using System.Collections.Generic;
using System.Text;
using EnvDTE;
using EnvDTE80;
using System.IO;

namespace ToolWindowAddin
{
	/// <summary>
	/// Helper class for building the item hierarchy for a project.
	/// </summary>
	public static class HierarchyBuilder
	{
		public static HierarchyItem ExploreSolution(Solution solution)
		{
			if (!solution.IsOpen)
			{
				return new HierarchyItem("No solution loaded");
			}

			string strRoot = "Solution " + Path.GetFileNameWithoutExtension(solution.FileName);
			HierarchyItem objRoot = new HierarchyItem(strRoot);

			foreach (Project objProject in solution)
			{
				objRoot.Children.Add(ExploreProject(objProject));
			}
			return objRoot;
		}

		/// <summary>
		/// Explores the hierarchy of the specified project.
		/// </summary>
		/// <param name="project">The project.</param>
		/// <returns></returns>
		private static HierarchyItem ExploreProject(Project project)
		{
			HierarchyItem objHierarchyItem = new HierarchyItem();
			try
			{
				objHierarchyItem.Text = "Project " + project.Name;
			}
			catch
			{
				objHierarchyItem.Text = "Project";
				return objHierarchyItem;
			}

			if (project.ProjectItems != null)
				AddProjectItems(project.ProjectItems, objHierarchyItem);

			return objHierarchyItem;
		}

		/// <summary>
		/// Adds the specified project items.
		/// </summary>
		/// <param name="projectItems">The project items.</param>
		/// <param name="parent">The parent of the items in the hierarchy.</param>
		private static void AddProjectItems(ProjectItems projectItems, HierarchyItem parent)
		{
			try
			{
				foreach (ProjectItem objProjectItem in projectItems)
					parent.Children.Add(ExploreProjectItem(objProjectItem));
			}
			catch
			{
			}
		}

		private static HierarchyItem ExploreProjectItem(ProjectItem projectItem)
		{
			HierarchyItem objHierarchyItem = new HierarchyItem();
			try
			{
				objHierarchyItem.Text = projectItem.Name;
			}
			catch
			{
				objHierarchyItem.Text = "(unknown project item)";
				return objHierarchyItem;
			}
			try
			{
				if (projectItem.ProjectItems != null)
				{
					foreach (ProjectItem objProjectItem in projectItem.ProjectItems)
						objHierarchyItem.Children.Add(ExploreProjectItem(objProjectItem));
				}
			}
			catch
			{
				// ignore
			}
			return objHierarchyItem;
		}
	}
}
